import React, {useState, useEffect} from 'react';
import {StyleSheet, View} from 'react-native';
import {enableScreens} from 'react-native-screens';
// REDUX DEBUGGING -- REMOVE BEFORE "RELEASE"
import {composeWithDevTools} from 'redux-devtools-extension';

// Redux set-up
import {createStore, combineReducers, applyMiddleware} from 'redux';
import {Provider} from 'react-redux';
import ReduxThunk from 'redux-thunk';
import initReducer from './store/reducers/reduce';

import Loading from './components/Loading';

//FONTS
import { useFonts } from '@use-expo/font';
import {AppLoading} from 'expo'

const rootReducer = combineReducers({
    init: initReducer
});

const store = createStore(rootReducer, composeWithDevTools(applyMiddleware(ReduxThunk)));

const App = () => {
    let [fontsLoaded] = useFonts({
        "MuseoSansRounded-300": require("./assets/fonts/MuseoSansRounded-300-webfont.ttf"),
        "MuseoSansRounded-500": require("./assets/fonts/MuseoSansRounded-500-webfont.ttf"),
        "MuseoSansRounded-700": require("./assets/fonts/MuseoSansRounded-700-webfont.ttf"),
        "MuseoSansRounded-900": require("./assets/fonts/MuseoSansRounded-900-webfont.ttf")
    });

    if (!fontsLoaded) {
        return (
            <AppLoading/>
        );
    }
    return (
        <Provider store={store}>
            <Loading/>
        </Provider>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        backgroundColor: '#fff',
        justifyContent: 'flex-start',
        alignItems: 'stretch',
        overflow: 'hidden'
    }
});

export default App;
