import React, { useEffect, useState } from 'react';
import { View, StyleSheet, ActivityIndicator, AppState } from 'react-native';
import { useDispatch, useSelector } from 'react-redux';
import { Notifications } from 'expo';
import Constants from 'expo-constants';
import * as LocalAuthentication from 'expo-local-authentication';

import * as actions from '../store/actions/action';
import BankIDLogin from '../screens/login/BankIDLogin';
import LocalAuth from '../screens/login/LocalAuthentication';
import MainNavigator from '../navigations/MainNavigator';

const Loading = () => {
  const dispatch = useDispatch();
  const loaded = useSelector(state => state.init.loading.loaded);
  const biometricLogin = useSelector(state => state.init.loading.biometric);
  const authenticated = useSelector(state => state.init.authenticated);
  const deviceToken = useSelector(state => state.init.loading.deviceToken);
  let timeBackgrounded = new Date();
  let timeForegrounded = new Date();

  const loadingPhase = async () => {
    if (Constants.isDevice) {
      const expoToken = await Notifications.getExpoPushTokenAsync();
      const hasBiometricHardware = await LocalAuthentication.supportedAuthenticationTypesAsync();
      dispatch(actions.loadingPhase(expoToken, hasBiometricHardware));
    } else {
      console.log('Not real device!');
    }
  };

  // AppState
  const [appState, setAppState] = useState(AppState.currentState);
  const minutesBetween = (timeB, timeF) => {
    let diff = (timeB.getTime() - timeF.getTime()) / 1000;
    diff /= 60;
    return Math.abs(Math.round(diff));
  };

  const handleAppStateChange = nextAppState => {
    if ((appState === 'inactive' || 'background') && nextAppState === 'active') {
      // App in foreground.
      timeForegrounded = new Date();
      if (minutesBetween(timeBackgrounded, timeForegrounded) >= 15) {
        timeBackgrounded = new Date();
        dispatch(actions.logOut(deviceToken, false));
      }
    }
    if ((appState === 'inactive' || 'foreground') && nextAppState === 'background') {
      // App in background.
      timeBackgrounded = new Date();
    }
    setAppState(nextAppState);
  };

  useEffect(() => {
    AppState.addEventListener('change', handleAppStateChange);
    return () => {
      AppState.removeEventListener('change', handleAppStateChange);
    };
  }, []);
  // End AppState

  useEffect(() => {
    console.log('[Loading.js] --> useEffect()');
    loadingPhase();
  }, [loaded]);

  if (loaded && biometricLogin) {
    return <LocalAuth />;
  }
  if (loaded && !biometricLogin) {
    return <BankIDLogin />;
  }
  if (authenticated) {
    return <MainNavigator />;
  }
  return (
    <View style={[styles.container, styles.horizontal]}>
      <ActivityIndicator size={'large'} color={'#00ff00'} />
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: 'center'
  },
  horizontal: {
    flexDirection: 'row',
    justifyContent: 'space-around',
    padding: 10
  }
});
export default Loading;
