const express = require('express');

const router = express.Router();
const mysql = require('mysql');
const config = require('../../config');

const pool = mysql.createPool({
    connectionLimit: 2,
    host: config.prod.host,
    user: config.prod.user,
    password: config.prod.password,
    database: config.prod.database,
    debug: false
});

const Ud = require('../dao/userDao');

const userDao = new Ud(pool);

/**
 * @name Get one user from the database
 * @memberof module:Routes
 * @route {GET} /user/:userId
 * @routeparam {String} [userId] The users unique userId.
 */
router.get('/:userId', (req, res) => {
    const {userId} = req.params;
    console.log('Handling GET request to /user/', userId);
    userDao.getOne(userId, (status, data) => {
        res.status(status);
        res.json(data);
    });
});

/**
 * @name Insert user to the userTable.
 * @memberof module:Routes
 * @route {PUT} /user
 * @bodyparam {String} [userId] The users unique userId.
 * @bodyparam {String} [expoToken] The users unique device expoToken.
 * @bodyparam {String} [orgType] The users organisationType.
 * @bodyparam {String} [ordId] The users organisationId.
 * @bodyparam {String} [orgName] The users organisationName.
 */
router.put('/', (req, res) => {
    console.log('Handling PUT request to /user');
    const {userId, expoToken, orgType, orgId, orgName} = req.body;
    userDao.insertUser(
        {
            userId: userId,
            expoToken: expoToken,
            orgType: orgType,
            orgId: orgId,
            orgName: orgName
        },
        (status, data) => {
            res.status(status);
            res.json(data);
        }
    );
});

module.exports = router;
