const mysql = require('mysql');

const BioDao = require('../api/dao/bioDao');
const runsqlfile = require('./runsqlfile');
const config = require('../config');

const pool = mysql.createPool({
  connectionLimit: 1,
  host: config.test.host,
  user: config.test.user,
  password: config.test.password,
  database: config.test.database,
  debug: false,
  multipleStatements: true
});

const bioDao = new BioDao(pool);

beforeAll(done => {
  runsqlfile('test/createTable.sql', pool, () => {
    runsqlfile('test/createTestData.sql', pool, done);
  });
});

function testCallback(status, data) {
  console.log('Test callback: ');
  console.log('Status = ', status);
  console.log('Data = ', JSON.stringify(data));
}

test('Test: Insert one into biometric table.', done => {
  function callback(status, data) {
    testCallback(status, data);
    expect(data[0].expoToken).toBe('IDontExistYet');
    done();
  }

  function getOne() {
    bioDao.getOne('IDontExistYet', callback);
  }
  bioDao.insertToken('IDontExistYet', getOne);
});

test('Test: Change biometric on one.', done => {
  function callback(status, data) {
    testCallback(status, data);
    expect(data[0].biometri).toBe(0);
    done();
  }
  function getOne() {
    bioDao.getOne('IDontExistYet', callback);
  }
  bioDao.setBiometric({ option: 0, tokenId: 'IDontExistYet' }, getOne);
});

test('Test: Change firstPrompt on one.', done => {
  function callback(status, data) {
    testCallback(status, data);
    // expect(data[0].exist.toBe(1));
    done();
  }
  function getOne() {
    bioDao.getOne('IDontExistYet', callback);
  }
  bioDao.setFirstPrompt({ option: 1, tokenId: 'IDontExistYet' }, getOne);
});

test('Test: Check if one exists in table.', done => {
  function callback(status, data) {
    testCallback(status, data);
    expect(data[0].exist).toBe(1);
    done();
  }
  bioDao.checkExist('IDontExistYet', callback);
});
