const mysql = require('mysql');

const NotificationDao = require('../api/dao/notificationDao');
const runsqlfile = require('./runsqlfile.js');
const config = require('../config');

const pool = mysql.createPool({
    connectionLimit: 1,
    host: config.test.host,
    user: config.test.user,
    password: config.test.password,
    database: config.test.database,
    debug: false,
    multipleStatements: true
});

const notificationDao = new NotificationDao(pool);

beforeAll(done => {
    runsqlfile('test/createTable.sql', pool, () => {
        runsqlfile('test/createTestData.sql', pool, done);
    });
});

function testCallback(status, data) {
    console.log('Test callback: ');
    console.log('Status = ', status);
    console.log('Data = ', JSON.stringify(data));
}

test('Insert user to notificationTable', done => {
    function callback(status, data) {
        testCallback(status, data);
        expect(data[0].notificationType).toBe('DOCUMENT_SIGNED');
        expect(data[0].description).toBe('Melding når en innskyter har signert dokumenter');
        expect(data[0].associationType).toBe('BANK');
        expect(data[0].notify).toBe(1);
        done();
    }

    function getOneUserSettings() {
        notificationDao.getSettings(
            {
                associationType: 'BANK',
                expoToken: 'UserOne'
            },
            callback
        );
    }

    notificationDao.insert(
        {
            expoToken: 'UserOne',
            notificationType: 'DOCUMENT_SIGNED',
            associationType: 'BANK'
        },
        getOneUserSettings
    );
});

test('Get all users in notificationTable', done => {
    function callback(status, data) {
        testCallback(status, data);
        expect(data.length).toBe(2);
        expect(data[0].expoToken).toBe('UserOne');
        expect(data[1].expoToken).toBe('UserTwo');
        done();
    }

    function getAll() {
        notificationDao.getAll('DOCUMENT_SIGNED', callback);
    }

    notificationDao.insert(
        {
            expoToken: 'UserTwo',
            notificationType: 'DOCUMENT_SIGNED',
            associationType: 'BANK'
        },
        getAll
    );
});

test('Update one users notify-setting', done => {
    function callback(status, data) {
        testCallback(status, data);
        expect(data[0].notify).toBe(0);
        done();
    }

    function getSettings() {
        notificationDao.getSettings(
            {
                associationType: 'BANK',
                expoToken: 'UserOne'
            },
            callback
        );
    }

    notificationDao.update(
        {
            newValue: 0,
            expoToken: 'UserOne',
            notificationType: 'DOCUMENT_SIGNED',
            associationType: 'BANK'
        },
        getSettings
    );
});
