const mysql = require('mysql');

const UserDao = require('../api/dao/userDao');
const runsqlfile = require('./runsqlfile.js');
const config = require('../config');

const pool = mysql.createPool({
  connectionLimit: 1,
  host: config.test.host,
  user: config.test.user,
  password: config.test.password,
  database: config.test.database,
  debug: false,
  multipleStatements: true
});

const userDao = new UserDao(pool);

beforeAll(done => {
  runsqlfile('test/createTable.sql', pool, () => {
    runsqlfile('test/createTestData.sql', pool, done);
  });
});

function testCallback(status, data) {
  console.log('Test callback: ');
  console.log('Status = ', status);
  console.log('Data = ', JSON.stringify(data));
}

test('Test: Insert existing user to userTable.', done => {
  function callback(status, data) {
    testCallback(status, data);
    expect(data[0].userId).toBe('9ab7492e-1430-4c81-9d8b-f4b9c1813db1');
    expect(data.length).toBe(1);
    done();
  }

  function getUser() {
    userDao.getOne('9ab7492e-1430-4c81-9d8b-f4b9c1813db1', callback);
  }

  userDao.insertUser(
    {
      userId: '9ab7492e-1430-4c81-9d8b-f4b9c1813db1',
      expoToken: 'ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]',
      orgType: 'BANK',
      orgId: '8b0b0b72-ff9b-40a4-9d3e-f700882644ff',
      orgName: 'Opdals Sparebank'
    },
    getUser
  );
});

test('Test: Insert new user to userTable.', done => {
  function callback(status, data) {
    testCallback(status, data);
    expect(data[0].userId).toBe('new_user_id');
    done();
  }

  function getUser() {
    userDao.getOne('new_user_id', callback);
  }

  userDao.insertUser(
    {
      userId: 'new_user_id',
      expoToken: 'ExponentPushToken[wp-05MLk8XkeZDxSH7YQqf]',
      orgType: 'DEPOSITOR',
      orgId: '8b0b0b72-ff9b-40a4-9d3e-f700882644ff',
      orgName: 'testorganisation'
    },
    getUser
  );
});

test('Test: Get all users from userTable on orgId', done => {
  function callback(status, data) {
    testCallback(status, data);
    data.forEach(element => {
      expect(element.orgId).toBe('8b0b0b72-ff9b-40a4-9d3e-f700882644ff');
    });
    expect(data.length).toBe(2);
    done();
  }
  userDao.getAllOrg('8b0b0b72-ff9b-40a4-9d3e-f700882644ff', callback);
});
