import dao.NotificationTableDao;
import org.json.JSONArray;

import java.nio.charset.StandardCharsets;
import java.util.ArrayList;


public class HandleNotification {


    private NotificationTableDao notificationTable = new NotificationTableDao();
    private ArrayList<String> expoTokens = new ArrayList<>();
    private int from = 0;
    private int to = 100;
    private final int MAX_USER_LIST = 100;

    private PostMessage pm;
    //private String errorMessage;
    private String title;
    private String body;
    private org.json.JSONObject data;
    private final String EXPO_HOST = "https://exp.host/--/api/v2/push/send";


    /**
     * Method for sending push-notifications,
     * checks if number of user to receive tokens exceeds Expo's max number for sending tokens
     * @param notificationType String
     * @param notificationTitle String
     * @param bodyMessage String
     * @param organisation_id String
     * @param associationType String
     */
    public void sendPushNotification (String notificationType, String notificationTitle, String bodyMessage, String organisation_id, String associationType) {

        data = new org.json.JSONObject();
        data.put("action",notificationType);
        data.put("associationType",associationType);

        expoTokens = notificationTable.getExpoTokens(associationType, notificationType, organisation_id);

        System.out.println("\n\nAll expoTokens to get PushNotification:\n" + expoTokens + "\n\n");

        title = new String(notificationTitle.getBytes(),StandardCharsets.ISO_8859_1);
        body = new String(bodyMessage.getBytes(),StandardCharsets.ISO_8859_1);

        data.put("title", title);
        data.put("body", body);

        if (expoTokens.size() >= MAX_USER_LIST) {
            int numbOfList = (expoTokens.size()/MAX_USER_LIST)+1;

            for  (int i = 0; i < numbOfList; i++) {
                if  (i == numbOfList-1) to = expoTokens.size();

                ArrayList<String> temp = new ArrayList<>(expoTokens.subList(from,to));
                from = to;
                to += MAX_USER_LIST;
                pm = new PostMessage(temp,title,body,data);
                pm.sendPost(EXPO_HOST);
            }

        } else {
            pm = new PostMessage(expoTokens,title,body,data);
            pm.sendPost(EXPO_HOST);
        }
        // errorHandling(pm);
    }


    /**
     * This method sends push notifications, for new ads on marketplace
     * @param notificationType String
     * @param notificationTitle String
     * @param bodyMessage String
     */
    public void sendNewADNotification (String notificationType,String notificationTitle, String bodyMessage) {
        data = new org.json.JSONObject();
        expoTokens = notificationTable.getExpoTokensForAD(notificationType);

        data.put("action",notificationType);

        System.out.println("\n\nAll expoTokens to get PushNotification for NEW_AD:\n" + expoTokens + "\n\n");

        title = new String(notificationTitle.getBytes(),StandardCharsets.ISO_8859_1);
        body = new String(bodyMessage.getBytes(),StandardCharsets.ISO_8859_1);

        data.put("title", title);
        data.put("body", body);


        if (expoTokens.size() >= MAX_USER_LIST) {
            int numbOfList = (expoTokens.size()/MAX_USER_LIST)+1;

            for  (int i = 0; i < numbOfList; i++) {
                if  (i == numbOfList-1) to = expoTokens.size();

                ArrayList<String> temp = new ArrayList<>(expoTokens.subList(from,to));
                from = to;
                to += MAX_USER_LIST;
                pm = new PostMessage(temp,title,body,data);
                pm.sendPost(EXPO_HOST);
            }

        } else {
            pm = new PostMessage(expoTokens,title,body,data);
            pm.sendPost(EXPO_HOST);
        }
    }



    /**
     * Fetching all expoTokens who wants notification on one specific event
     * Sending push-notification to users, with title, and body message.
     *
     * @param notificationType String
     * @param notificationTitle String
     * @param bodyMessage String
     */
    public void handleNotification (String notificationType, String notificationTitle, String bodyMessage) {
        data = new org.json.JSONObject();

        expoTokens = notificationTable.getExpoTokenByNotificationType(notificationType);

        title = new String(notificationTitle.getBytes(), StandardCharsets.ISO_8859_1);
        body = new String(bodyMessage.getBytes(), StandardCharsets.ISO_8859_1);

        if (expoTokens.size() >= MAX_USER_LIST) {
            int numbOfList = (expoTokens.size()/MAX_USER_LIST)+1;

            for  (int i = 0; i < numbOfList; i++) {
                if  (i == numbOfList-1) to = expoTokens.size();

                ArrayList<String> temp = new ArrayList<>(expoTokens.subList(from,to));
                from = to;
                to += MAX_USER_LIST;
                pm = new PostMessage(temp,title,body,data);
                pm.sendPost(EXPO_HOST);
            }

        } else {
            pm = new PostMessage(expoTokens,title,body,data);
            pm.sendPost(EXPO_HOST);
        }


    }


    /**
     * Error handling if push-receipts throws error
     * DeviceNotRegistered, MessageTooBig, MessageRateExceeded, InvalidCredentials
     * @param pm PostMessage
     */
    public void errorHandling(PostMessage pm){
        org.json.JSONObject response = pm.getJSONOBJECT();
        JSONArray responseObject = response.getJSONArray("data");

        for (int i = 0; i < responseObject.length(); i++ ) {

            if (responseObject.getJSONObject(i).getString("status").equals("error")) {
                String errorMessage = responseObject.getJSONObject(i).getJSONObject("details").getString("error");

                String detailMessage = responseObject.getJSONObject(i).getString("message");
                String[] tmp = detailMessage.split(" ");
                String msg = tmp[0].replace("\""," ").trim();

                switch (errorMessage) {
                    case "DeviceNotRegistered":
                        /**
                         * the device cannot receive push notifications anymore and
                         * Deleting expoToken from database, need to stop sending messages to the corresponding Expo-push-token.
                         */
                        System.out.println(msg);
                        System.out.println("DeviceNotRegistered: \t"+ msg +", deleting expoToken from database");
                        notificationTable.deleteTokeId(msg);
                        break;

                    case "MessageTooBig":
                        /**
                         * the total notification payload was too large.
                         * On Android and iOS the total payload must be at most 4096 bytes.
                         */
                        System.out.println("MessageTooBig:\t" + msg);
                        System.out.println("Payload exceeds 4096 bytes");
                        break;

                    case "MessageRateExceeded":
                        /**
                         * you are sending messages too frequently to the given device.
                         * Implement exponential backoff and slowly retry sending messages.
                         */
                        System.out.println("MessageRateExceeded...:" + msg);
                        break;

                    case "InvalidCredentials":
                        /**
                         *  your push notification credentials for your standalone app are invalid
                         *  (ex: you may have revoked them).
                         *  Run expo build:ios -c to regenerate new push notification credentials for iOS.
                         */
                        System.out.println("InvalidCredentials...:" + msg);
                        System.out.println("Run command:  'expo build:ios -c' to regenerate new push notification credentials for IOS");
                        break;
                }
            }
        }
    }

}