import org.apache.http.client.config.CookieSpecs;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClientBuilder;
import org.apache.http.util.EntityUtils;
import org.json.JSONObject;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;

public class PostMessage {

    private ArrayList<String> to;
    private String title;
    private String body;
    private JSONObject reponse;
    private JSONObject data;

    public PostMessage(ArrayList<String> to, String title, String body, JSONObject data) {
        this.to = to;
        this.title = title;
        this.body = body;
        this.data = data;
    }
    public PostMessage(ArrayList<String> to, String title, String body) {
        this.to = to;
        this.title = title;
        this.body = body;
    }

    public String getTitle() {
        return title;
    }
    public void setTitle(String title) {
        this.title = title;
    }

    public ArrayList<String> getTo() {
        return to;
    }
    public void setTo(ArrayList<String> to) { this.to = to; }

    public String getBody() {
        return body;
    }
    public void setBody(String body) {
        this.body = body;
    }

    public JSONObject getData () {
        return data;
    }
    public void setData (JSONObject data) {
        this.data = data;
    }

    /**
     * Creates a push notification json object
     * This json object is gets posted to Exps's api for push notification
     * @param to ArrayList
     * @param title String
     * @param body String
     * @param data JSONObject
     * @return JSONObject
     */
    public JSONObject createJSONObject (ArrayList<String> to, String title, String body, JSONObject data) {
        JSONObject json = new JSONObject();
        json.put("to",to);
        json.put("sound","default");
        json.put("title",title);
        json.put("body",body);
        json.put("data",data);

        return json;
    }

    public JSONObject getJSONOBJECT () {
        return reponse;
    }
    public void setJSONOBJECT (JSONObject obj) {
        reponse = obj;
    }

    /**
     * Http POST method
     * HttpClient has difficulty understanding latest RFC-compliant headers, switching to a standard cookie spec (HttpClient 4.4+)
     * @param url String
     */
    public void sendPost (String url) {
        CloseableHttpClient client = HttpClientBuilder.create()
                .setDefaultRequestConfig(RequestConfig.custom()
                    .setCookieSpec(CookieSpecs.STANDARD).build())
                .build();

        HttpPost httpPost = new HttpPost(url);


        try {
            StringEntity entity = new StringEntity(String.valueOf(createJSONObject(getTo(),getTitle(),getBody(),getData())));
            httpPost.setEntity(entity);

            httpPost.setHeader("Content-Type","application/json");
            httpPost.setHeader("Accept","application/json");

            try {
                CloseableHttpResponse response = client.execute(httpPost);

                System.out.println("\nstatusCode: " + response.getStatusLine().getStatusCode());
                String responseJSON = EntityUtils.toString(response.getEntity());


                JSONObject jsonObject = new JSONObject(responseJSON);
                System.out.println("JSON: " + jsonObject + "\n\n");
                setJSONOBJECT(jsonObject);
            } catch ( IOException ioe) {
                ioe.printStackTrace();
            }

        } catch (UnsupportedEncodingException uee) {
            uee.printStackTrace();
        }
    }
}
