import dao.*;
import database.ConfigProperties;
import dto.Order;

import com.rabbitmq.client.Channel;
import com.rabbitmq.client.Connection;
import com.rabbitmq.client.ConnectionFactory;
import com.rabbitmq.client.DeliverCallback;

import java.io.*;
import org.json.simple.parser.JSONParser;
import java.nio.charset.StandardCharsets;


/**
 * work queue, handles incoming events and pushes notifications to users
 * class Receiver
 */

public class Reciever {

    private static File currentDir = new File("rabbitMQ/src/config.properties");
    private static String configFile = currentDir.getAbsolutePath();
    private static ConfigProperties databaseConfig = new ConfigProperties(configFile);


    private static final String QUEUE_NAME_FIXRATE = databaseConfig.getRabbitMQqueueName("rabbitMQ");
    private static final String FIXRATE_HOST = databaseConfig.getRabbitMQHost("rabbitMQ");
    private static final String FIXRATE_USERNAME = databaseConfig.getRabbitMQuserName("rabbitMQ");
    private static final String FIXRATE_PASSWORD =  databaseConfig.getRabbitMQpassword("rabbitMQ");
    private static String type;
    private static String nextState;

    private static String ad_id;
    private static String user_id;
    private static String bank_id;
    private static String order_id;
    private static String process_id;
    private static String depositor_id;
    private static String organisation_id;

    private static String bankName;
    private static String organisationName;
    private static String depositorFirstname;
    private static String depositorLastname;
    private static String depositorFullname;

    private static FixrateDBDao fixrateDBDao = new FixrateDBDao();
    private static OrderDao orderDao = new OrderDao();
    private static Order order = new Order();

    private static HandleNotification hn = new HandleNotification();


    /**
     * Writing events to file
     * only function to get more static overview on different events from Fixrate's rabbitMQ
     * @param message String
     */
    public static void writeToFile(String message) {
        try {
            String filepath = new File("rabbitMQ/src/main/resources/events.json").getAbsolutePath();
            BufferedWriter writer = new BufferedWriter(new FileWriter(filepath, true));
            writer.newLine();
            writer.write(message + ",");
            writer.close();
        } catch (IOException ioe) {
            ioe.printStackTrace();
        }
    }


    /**
     * Main method
     * Handles different event types from Fixrate's web-application
     * @param args String
     */

    public static void main(String[] args) throws Exception {
        ConnectionFactory factory = new ConnectionFactory();
        factory.setHost(FIXRATE_HOST);
        factory.setUsername(FIXRATE_USERNAME);
        factory.setPassword(FIXRATE_PASSWORD);
        Connection connection = factory.newConnection();
        Channel channel = connection.createChannel();

        channel.queueDeclare(QUEUE_NAME_FIXRATE, false, false, false, null);
        channel.exchangeDeclare(QUEUE_NAME_FIXRATE, "fanout");
        String queue_name = channel.queueDeclare().getQueue();
        channel.queueBind(queue_name, QUEUE_NAME_FIXRATE, "");

        System.out.println("Listening to Fixrate's rabbitMQ");
        System.out.println("[*] Waiting for message from produces... \n\n");


        /**
         * Callback function to receive events from Fixrate's rabbitMQ server
         */
        DeliverCallback deliverCallback = (consumerTag, delivery) -> {

            String message = new String(delivery.getBody(), StandardCharsets.UTF_8);
            //System.out.println("deliveryCallback: " + message);

            JSONParser parser = new JSONParser();
            org.json.simple.JSONObject json;
            org.json.JSONObject jsonObject;

            try {
                /**
                 * Parsing message from deliverCallback with org.json.simple, then create org.json object
                 * to be able to fetch values from in that json object with updating json.simple to org.json.JSONObject
                 */
                json = (org.json.simple.JSONObject) parser.parse(message);
                jsonObject = new org.json.JSONObject(json);
                type = jsonObject.getString("type");

                /**
                 * Sending push-notification relative to type of event
                 * @type String event
                 */
                switch (type) {
                    case "AdCreated":
                        ad_id = jsonObject.getJSONObject("event").getString("identity");
                        bankName = fixrateDBDao.getBankNameFromAd(ad_id);

                        hn.sendNewADNotification(
                                "NEW_AD",
                                "Ny annonse er lagt til på markedplassen",
                                bankName + " har lagt til ny annonse på markedsplassen");
                        break;

                    case "OrderSentToBank":
                        order_id = jsonObject.getJSONObject("event").getString("identity");
                        user_id = jsonObject.getJSONObject("event").getString("userId");

                        order = orderDao.getOrderInfo(user_id, order_id);
                        bank_id = order.getBankId();
                        organisation_id = order.getOrganisationId();

                        nextState = jsonObject.getJSONObject("event").getString("nextState");
                        System.out.println("OrderSentToBank nextState: .." + nextState);

                        depositorFirstname = order.getDepositorFirstname();
                        depositorLastname = order.getDepositorLastname();
                        organisationName = order.getOrganisationName();

                        switch (nextState) {
                            case "INITIAL_PROCESSING":
                                System.out.println("\nNew order from depositor: " + jsonObject);
                                hn.sendPushNotification(
                                        "NEW_ORDER",
                                        "Nytt innskudd på Fixrate",
                                        "Du har fått en ny bestilling fra " + depositorFirstname + " " + depositorLastname + " hos " + organisationName,
                                        bank_id, "BANK");
                                break;

                            case "READY_FOR_APPROVAL":
                                System.out.println("Document signed by depositor: " + jsonObject);
                                hn.sendPushNotification(
                                        "DOCUMENT_SIGNED",
                                        "Signert kontoavtale klar hos Fixrate",
                                        "Du har mottatt signerte dokumenter fra " + depositorFirstname + " " + depositorLastname + " hos " + organisationName,
                                        bank_id, "BANK");
                                break;

                            case "READY_FOR_TRANSACTION_CONFIRMATION":
                                System.out.println("Transaction confirmed by depositor: " + jsonObject);
                                hn.sendPushNotification(
                                        "ORDER_COMPLETED",
                                        "Innskudd er satt inn på konto",
                                        depositorFirstname + " " + depositorLastname + " hos " + organisationName + " har bekreftet via Fixrate at innskuddet er overført i sin helhet til konto",
                                        bank_id, "BANK");
                                break;
                        }
                        break;


                    case "OrderSentToDepositor":
                        order_id = jsonObject.getJSONObject("event").getString("identity");
                        user_id = jsonObject.getJSONObject("event").getString("userId");

                        order = orderDao.getOrderInfo(user_id, order_id);
                        organisation_id = order.getOrganisationId();
                        organisationName = order.getOrganisationName();
                        bankName = order.getBankName();

                        nextState = jsonObject.getJSONObject("event").getString("nextState");
                        System.out.println("OrderSentToDepositor nextState: .." + nextState);
                        switch (nextState) {
                            case "READY_FOR_SIGNING":
                                System.out.println("Document ready for signing: " + jsonObject);
                                hn.sendPushNotification(
                                        "DOCUMENT_READY_FOR_SIGNING",
                                        "Kontoavtale er klar for signering hos Fixrate",
                                        bankName + " har laget en kontoavtale for " + organisationName + " som ligger klar for signering hos Fixrate",
                                        organisation_id, "DEPOSITOR");
                                break;

                            case "READY_FOR_TRANSACTION":
                                System.out.println("Account activated, and Ready for transaction: " + jsonObject);
                                hn.sendPushNotification(
                                        "ACCOUNT_ACTIVATED",
                                        "Klart for overføring av innskudd på Fixrate",
                                        bankName + " har aktivert din nye konto og venter på overføring av penger",
                                        organisation_id, "DEPOSITOR");
                                break;
                        }
                        break;

                    case "InterestRateChangeMessageSentToDepositor":
                        System.out.println("\n\n Interest of change created: " + jsonObject);
                        order_id = jsonObject.getJSONObject("event").getString("identity");

                        order = orderDao.getRateChangeInfo(order_id);
                        organisation_id = order.getOrganisationId();
                        bankName = order.getBankName();
                        organisationName = order.getOrganisationName();
                        hn.sendPushNotification(
                                "INTEREST_RATE_CHANGE_MESSAGE",
                                "Melding fra bank om renteendring på innskudd",
                                bankName + " har sendt melding til " + organisationName + " om renteendring på ett innskudd",
                                organisation_id, "DEPOSITOR");
                        break;

                    case "OrderCancelled":
                        System.out.println("OrderCancelled: " + jsonObject);
                        order_id = jsonObject.getJSONObject("event").getString("identity");

                        order = orderDao.getCancelledOrderInfo(order_id);
                        bankName = order.getBankName();
                        organisationName = order.getOrganisationName();
                        organisation_id = order.getOrganisationId();
                        System.out.println("bankname: " + bankName);
                        System.out.println("organisationName: " + organisationName);
                        hn.sendPushNotification(
                                "ORDER_CANCELLED",
                                "Innskdd avvist",
                                "Et innskudd fra " + organisationName + " har blitt avvist fra " + bankName,
                                organisation_id,"DEPOSITOR");
                        break;

                    case "DepositTerminationRequested":
                        System.out.println("\n\n Oppsigelse av innskudd fra innskyter " + jsonObject);

                        process_id = jsonObject.getJSONObject("event").getString("identity");
                        order = orderDao.getDepositTerminationRequestInfo(process_id);
                        depositorFullname = order.getDepositorFullname();
                        organisationName = order.getOrganisationName();
                        bank_id = order.getBankId();
                        hn.sendPushNotification(
                                "DEPOSIT_TERMINATED",
                                "Oppsigelse av innskudd",
                                "Du har mottatt en oppsigelse fra " + depositorFullname + " hos " + organisationName + " via Fixrate",
                                bank_id,"BANK");
                        break;

                    case "DepositTerminationConfirmed":
                        System.out.println("Oppsigelse bekreftet av bank " + jsonObject);

                        process_id = jsonObject.getJSONObject("event").getString("identity");
                        order = orderDao.getDepositTerminationConfirmedInfo(process_id);
                        organisationName = order.getOrganisationName();
                        organisation_id = order.getOrganisationId();
                        bank_id = order.getBankId();
                        hn.sendPushNotification(
                                "DEPOSIT_TERMINATED",
                                "Oppsigelse av innskudd i Fixrate er bekreftet i banken",
                                "Oppsigelse på et innskudd gjort av " + organisationName + " gjennom Fixrate er bekreftet av banken",
                                organisation_id,"DEPOSITOR");
                        break;
                }

            } catch (Exception e) {
                System.out.println("error parsing jsonObject!");
                e.printStackTrace();
            }
            //writeToFile(message);
        };
        channel.basicConsume(queue_name, true, deliverCallback, consumerTag -> {});
    }
}