package dao;

import database.Database;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;

import static database.Database.close;

public class NotificationTableDao {
    private Database db = new Database();
    private Connection connection = null;
    private ResultSet res = null;
    private PreparedStatement preparedStatement = null;


    /**
     * Finds all ExpoTokens based on one notification type
     * @param column String
     * @return ArrayList, This returns an arrayList of ExpoTokens
     */
    public ArrayList<String> getExpoTokenByNotificationType (String column)  {
        String sqlQuery = "SELECT expoToken FROM testTok.notificationTable WHERE notificationType = ? AND notify = ?;";
        ArrayList<String> expoTokens = new ArrayList<>();
        try {
            connection = db.connect();
            preparedStatement = connection.prepareStatement(sqlQuery);
            preparedStatement.setString(1,column);
            preparedStatement.setInt(2,1);
            res = preparedStatement.executeQuery();

            while(res.next()) expoTokens.add(res.getString("expoToken"));

        } catch (SQLException sqle) {
            sqle.printStackTrace();
        }  finally {
            close(connection,preparedStatement,res);
        }
        return expoTokens;
    }

    /**
     * Finds ExpoTokens based association type, notification type, and organisation id
     * @param associationType String
     * @param notificationType String
     * @param organisation_id String
     * @return ArrayList, This returns an arrayList of ExpoTokens
     */
    public ArrayList<String> getExpoTokens (String associationType, String notificationType, String organisation_id) {
        String query = "SELECT nt.expoToken FROM testTok.userTable ut " +
                        "JOIN testTok.notificationTable nt ON ut.expoToken = nt.expoToken AND nt.associationType = ut.orgType " +
                        "WHERE ut.orgType = ? AND nt.notify = ? AND nt.notificationType = ? AND ut.orgId = ?;";

        ArrayList<String> expotokens = new ArrayList<>();
        try {
            connection = db.connect();
            preparedStatement = connection.prepareStatement(query);
            preparedStatement.setString(1,associationType);
            preparedStatement.setInt(2,1);
            preparedStatement.setString(3,notificationType);
            preparedStatement.setString(4,organisation_id);

            System.out.println("\nassociationType: " + associationType);
            System.out.println("notificationType: " + notificationType);
            System.out.println("organisation_id: " + organisation_id);

            res = preparedStatement.executeQuery();

            while (res.next()) expotokens.add(res.getString("expoToken"));

        } catch (SQLException sqle) {
            sqle.printStackTrace();
        } finally {
            close(connection,preparedStatement,res);
        }
        return expotokens;
    }

    /**
     * Finds all ExpoTokens based on notification type, used to notify user's who want notification for new ads
     * @param notificationType String
     * @return ArrayList, This returns an arrayList of ExpoTokens
     */
    public ArrayList<String> getExpoTokensForAD (String notificationType) {
        String query =
                "SELECT DISTINCT nt.expoToken FROM testTok.userTable ut "+
                "JOIN testTok.notificationTable nt " +
                "WHERE nt.notify = ? " +
                "AND nt.notificationType = ? ";
        ArrayList<String> expoTokens = new ArrayList<>();
        try {
            connection  = db.connect();
            preparedStatement = connection.prepareStatement(query);
            preparedStatement.setInt(1,1);
            preparedStatement.setString(2,notificationType);
            res = preparedStatement.executeQuery();

            while (res.next()) expoTokens.add(res.getString("expoToken"));
            return expoTokens;
        } catch (SQLException sqle) {
            sqle.printStackTrace();
        } finally {
            close(connection, preparedStatement, res);
        }
        return null;
    }

    /**
     * This method removes ExpoToken from database, used in cases where ExpoToken is no longer valid
     * @param expoToken String
     */
    public void deleteTokeId (String expoToken) {
        String sqlQuery = "DELETE FROM testTok.notificationTable WHERE expoToken = ?";
        String query = "DELETE testTok.userTable.*, testTok.notificationTable.* FROM testTok.userTable JOIN testTok.notificationTable ON userTable.expoToken = notificationTable.expoToken WHERE userTable.expoToken = ?";

        try {
            connection = db.connect();
            preparedStatement = connection.prepareStatement(query);
            preparedStatement.setString(1,expoToken);
            preparedStatement.executeUpdate();
        } catch (SQLException sqle) {
            sqle.printStackTrace();
        } finally {
            close(connection,preparedStatement,res);
        }
    }
}
