package database;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

public class ConfigProperties {
    private String url;
    private String user;
    private String queueName;
    private String host;
    private String password;
    private String configFile;

    /**
     * Constructor ConfigProperties
     * @param configFile, file path
     */

    public ConfigProperties (String configFile) {
        this.configFile = configFile;
    }

    /**
     * Method to get url
     * @param database String
     * @return a url to given database
     */
    public String getUrl (String database) {
        try (InputStream input = new FileInputStream(configFile)) {
            Properties prop = new Properties();
            prop.load(input);
            url = prop.getProperty(database+".db.url");
        } catch (IOException e) {
            e.printStackTrace();
        }
        return url;
    }

    /**
     * Method to get username
     * @param database Sring
     * @return username to given database
     */
    public String getUsername (String database) {
        try (InputStream input = new FileInputStream(configFile)) {
            Properties prop = new Properties();
            prop.load(input);
            user = prop.getProperty(database+".db.user");
        } catch (IOException e) {
            e.printStackTrace();
        }
        return user;
    }


    /**
     * Method to get password
     * @param database String
     * @return password for given database
     */
    public String getPassword (String database) {
        try (InputStream input = new FileInputStream(configFile)) {
            Properties prop = new Properties();
            prop.load(input);
            password = prop.getProperty(database+".db.password");
        } catch (IOException e) {
            e.printStackTrace();
        }
        return password;
    }

    /**
     * Method to get queueName for rabbitMQ server
     * @param database String
     * @return rabbitMQ queueName
     */

    public String getRabbitMQqueueName (String database) {
        try (InputStream input = new FileInputStream(configFile)) {
            Properties prop = new Properties();
            prop.load(input);
            queueName = prop.getProperty(database+".queueName");
        } catch (IOException ioe) {
            ioe.printStackTrace();
        }
        return queueName;
    }

    /**
     * Method to get host name for rabbitMQ server()
     * @param database String
     * @return rabbitMQ host name
     */
    public String getRabbitMQHost (String database) {
        try (InputStream input = new FileInputStream(configFile)) {
            Properties prop = new Properties();
            prop.load(input);
            host = prop.getProperty(database+".host");
        } catch (IOException ioe) {
            ioe.printStackTrace();
        }
        return host;
    }

    /**
     * Method to get username for rabbitMQ server
     * @param database String
     * @return username for rabbitMQ
     */
    public String getRabbitMQuserName (String database) {
        try (InputStream input = new FileInputStream(configFile)) {
            Properties prop = new Properties();
            prop.load(input);
            user = prop.getProperty(database+".username");
        } catch (IOException ioe) {
            ioe.printStackTrace();
        }
        return user;
    }

    /**
     * Method to get password for rabbitMQ server
     * @param database String
     * @return password for rabbitMQ
     */
    public String getRabbitMQpassword (String database) {
        try (InputStream input = new FileInputStream(configFile)) {
            Properties prop = new Properties();
            prop.load(input);
            password = prop.getProperty(database+".password");
        } catch (IOException ioe) {
            ioe.printStackTrace();
        }
        return password;
    }
}
