package database;


import java.io.File;
import java.sql.*;
import java.util.Arrays;
import java.util.List;


public class Database {

    private static File currentDir = new File("rabbitMQ/src/config.properties");
    private static File currentDirTest = new File("src/config.properties");
    private static String configFile = currentDir.getAbsolutePath();
    private static String configFileTest = currentDirTest.getAbsolutePath();
    private static ConfigProperties databaseConfig = new ConfigProperties(configFile);
    private static ConfigProperties databaseConfigTest = new ConfigProperties(configFileTest);


    private static boolean isTest = isJUnitTest();

    private static final String JDBC_DRIVER = "com.mysql.jdbc.Driver";

    private static String PROD_DB_URL;
    private static String PROD_DB_USERNAME;
    private static String PROD_DB_PW;

    private static String TEST_DB_URL;
    private static String TEST_DB_USERNAME;
    private static String TEST_DB_PW;


    private Connection connection = null;

    /**
     * Method for checking if we are connecting to test database or production database
     * Using test database properties if className type is JUnit
     * @return boolean
     */
    public static boolean isJUnitTest() {
        StackTraceElement[] stackTrace = Thread.currentThread().getStackTrace();
        List<StackTraceElement> list = Arrays.asList(stackTrace);
        for (StackTraceElement element : list) {
            if (element.getClassName().startsWith("org.junit.")) {
                return true;
            }
        }
        return false;
    }

    /**
     * connect() using private method isJUnitTest(),
     * that checks if connection is established through unit testing or production,
     * and selects database accordingly
     * @return connection
     */
    public Connection connect() {
        try {
            Class.forName(JDBC_DRIVER);
            if (isTest) {
                TEST_DB_URL = databaseConfigTest.getUrl("test");
                TEST_DB_USERNAME = databaseConfigTest.getUsername("test");
                TEST_DB_PW = databaseConfigTest.getPassword("test");
                connection = DriverManager.getConnection(TEST_DB_URL,TEST_DB_USERNAME,TEST_DB_PW);

            }else  {
                PROD_DB_URL = databaseConfig.getUrl("prod");
                PROD_DB_USERNAME = databaseConfig.getUsername("prod");
                PROD_DB_PW = databaseConfig.getPassword("prod");
                connection = DriverManager.getConnection(PROD_DB_URL,PROD_DB_USERNAME,PROD_DB_PW);
            }
        } catch (SQLException | ClassNotFoundException sqle) {
            sqle.printStackTrace();
        }
        return connection;
    }


    /**
     * Static method for closing connection, preparedStatement, and resultSet
     * @param connection Connection
     * @param preparedStatement PreparedStatement
     * @param resultSet ResultSet
     */
    public static void close(Connection connection, PreparedStatement preparedStatement, ResultSet resultSet) {
        if (resultSet != null) {
            try {
                resultSet.close();
            } catch (SQLException e) {
                e.printStackTrace();
            }
        }
        if (preparedStatement != null) {
            try {
                preparedStatement.close();
            } catch (SQLException e) {
                e.printStackTrace();
            }
        }
        if (connection != null) {
            try {
                connection.close();
            } catch (SQLException e) {
                e.printStackTrace();
            }
        }

    }
}
