import database.Database;
import dao.NotificationTableDao;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import static org.junit.Assert.*;


public class NotificationDaoTest {
    private Connection connection;
    private NotificationTableDao notificationTableDao;
    private Statement statement;
    private Database db = new Database();


    @Before
    public void setUp () throws SQLException {
        try {
            connection = db.connect();
            notificationTableDao = new NotificationTableDao();
            statement = connection.createStatement();
        } catch (SQLException e) {
            e.printStackTrace();
        }

        String dropTable = "DROP TABLE IF EXISTS testTok.notificationTable";
        String creatTable =
                "CREATE TABLE testTok.notificationTable (" +
                    "expoToken VARCHAR (120) DEFAULT NULL," +
                    "notificationType VARCHAR (120) DEFAULT NULL," +
                    "associationType VARCHAR (45) DEFAULT NULL," +
                    "notify tinyint(4) DEFAULT '1'" +
                    ") ENGINE=InnoDB DEFAULT CHARSET=latin1";

        String insertStatement = "INSERT INTO testTok.notificationTable (expoToken,notificationType,associationType,notify) VALUES ('ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]','NEW_AD','DEPOSITOR',1);";
        String insertStatement2 = "INSERT INTO testTok.notificationTable (expoToken,notificationType,associationType,notify) VALUES ('ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]','NEW_AD','DEPOSITOR',1);";
        String insertStatement3 = "INSERT INTO testTok.notificationTable (expoToken,notificationType,associationType,notify) VALUES ('ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]','NEW_AD','DEPOSITOR',1);";
        String insertStatement4 = "INSERT INTO testTok.notificationTable (expoToken,notificationType,associationType,notify) VALUES ('ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]','COMPLETED','DEPOSITOR',1);";
        String insertStatement5 = "INSERT INTO testTok.notificationTable (expoToken,notificationType,associationType,notify) VALUES ('ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]','CANCELLED','BANK',0);";
        String insertStatement6 = "INSERT INTO testTok.notificationTable (expoToken,notificationType,associationType,notify) VALUES ('ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]','NEW_ORDER','BANK',1);";
        String insertStatement7 = "INSERT INTO testTok.notificationTable (expoToken,notificationType,associationType,notify) VALUES ('ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]1','DOCUMENT_READY_FOR_SIGNING','BANK',1);";
        String insertStatement8 = "INSERT INTO testTok.notificationTable (expoToken,notificationType,associationType,notify) VALUES ('ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]2','DOCUMENT_READY_FOR_SIGNING','BANK',1);";
        String insertStatement9 = "INSERT INTO testTok.notificationTable (expoToken,notificationType,associationType,notify) VALUES ('ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]3','DOCUMENT_READY_FOR_SIGNING','BANK',1);";

        try {
            statement.executeUpdate(dropTable);
            statement.executeUpdate(creatTable);
            statement.executeUpdate(insertStatement);
            statement.executeUpdate(insertStatement2);
            statement.executeUpdate(insertStatement3);
            statement.executeUpdate(insertStatement4);
            statement.executeUpdate(insertStatement5);
            statement.executeUpdate(insertStatement6);
            statement.executeUpdate(insertStatement7);
            statement.executeUpdate(insertStatement8);
            statement.executeUpdate(insertStatement9);
        } catch (SQLException sqle) {
            sqle.printStackTrace();
        } finally {
            statement.close();
        }
    }


    @After
    public void tearDown () {
        try {
            notificationTableDao = null;
            connection.close();
        } catch (SQLException e) {
            e.printStackTrace();
        }
    }


    @Test
    public void testGetExpoTokenByNotificationType () {
        ArrayList<String> tokens = notificationTableDao.getExpoTokenByNotificationType("COMPLETED");
        String expoToken = "ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]";
        int numberOfTokens = 1;
        assertEquals(expoToken,tokens.get(0));
        assertEquals(numberOfTokens, tokens.size());
    }

    @Test
    public void  testGetExpoTokens () {
        String associationType = "BANK";
        String notificationType = "NEW_ORDER";
        String organisation_id = "8b0b0b72-ff9b-40a4-9d3e-f700882644ff";
        String token = "ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]";
        ArrayList<String> tokens = notificationTableDao.getExpoTokens(associationType,notificationType,organisation_id);
        assertEquals(token,tokens.get(0));
    }


    @Test
    public void testGetExpoTokensForAd () {
        String notificationType = "NEW_AD";
        String expectedToken = "ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]";
        int numberOfTokens = 3;
        ArrayList<String> tokens = notificationTableDao.getExpoTokensForAD(notificationType);
        assertEquals(expectedToken, tokens.get(0));
        assertEquals(numberOfTokens, tokens.size());

    }

    @Test
    public void testDeleteTokenId () {
        String expoToken = "ExponentPushToken[wp-05MLk8XkeZDxSH7YQmp]1";
        int numberOftokensBefore = 3;
        int numberOftokensAfter = 2;
        ArrayList<String> tokens = notificationTableDao.getExpoTokenByNotificationType("DOCUMENT_READY_FOR_SIGNING");
        assertEquals(numberOftokensBefore,tokens.size());
        notificationTableDao.deleteTokeId(expoToken);
        tokens = notificationTableDao.getExpoTokenByNotificationType("DOCUMENT_READY_FOR_SIGNING");
        assertEquals(numberOftokensAfter,tokens.size());

    }



}
