import React, { useEffect } from 'react';
import { StyleSheet, View, Text, ScrollView } from 'react-native';
import { useSelector, useDispatch } from 'react-redux';

import * as actions from '../../store/actions/action';

import DashboardScrollBar from './DashboardScrollBar';
import ForTermination from './bank/forTermination';

const DashBoardDepo = () => {
  const { dashboardData } = useSelector(state => state.init);

  const dispatch = useDispatch();

  useEffect(() => {
    dispatch(actions.getDashboardData());
  }, []);

  return (
    <View style={styles.background}>
      <DashboardScrollBar />
      <View style={styles.container}>
        <View style={styles.header}>
          <Text style={styles.headerText}>Forfall avtaler</Text>
        </View>
        <ScrollView style={styles.content}>
          {dashboardData.map((deposit, i) => {
            return <ForTermination deposit={deposit} date={deposit.expire} ftKey={i} />;
          })}
        </ScrollView>
      </View>
    </View>
  );
};

const primaryText = 'MuseoSansRounded-700';
const primaryTextBold = 'MuseoSansRounded-900';

const styles = StyleSheet.create({
  background: {
    flex: 1,
    backgroundColor: '#EEEEEE'
  },
  container: {
    alignItems: 'center',
    backgroundColor: '#6699CC',
    margin: 20,
    paddingTop: 5,
    borderWidth: 1,
    borderColor: '#6699CC',
    borderRadius: 15,
    overflow: 'hidden'
  },
  content: {
    flexDirection: 'column',
    backgroundColor: 'white',
    width: '100%',
    paddingBottom: 25
  },
  header: {
    alignItems: 'center',
    paddingBottom: 5,
    width: '100%',
    borderBottomColor: 'black',
    borderBottomWidth: 0.5,
    backgroundColor: '#6699CC'
  },
  headerText: {
    fontFamily: primaryTextBold,
    fontSize: 36,
    color: 'white',
    textAlign: 'center'
  },
  primaryText: {
    fontFamily: primaryTextBold,
    fontSize: 32,
    color: 'rgba(0, 0, 0, 0.5)',
    textAlign: 'center'
  },
  secondaryText: {
    fontFamily: primaryText,
    fontSize: 28,
    color: 'rgba(0, 0, 0, 1)',
    textAlign: 'center'
  }
});

export default DashBoardDepo;
