import React, { useEffect } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { StyleSheet, View, Text, ScrollView } from 'react-native';

import * as actions from '../../store/actions/action';
import DashboardScrollBar from './DashboardScrollBar';
import Products from './bank/products';
import ForTermination from './bank/forTermination';

const DashboardBank = () => {
  const dispatch = useDispatch();
  const { dashboardData } = useSelector(state => state.init);

  const fixedDeposits = [];
  const sortedProducts = [
    {
      product: '31 d',
      quantity: 0,
      volume: 0
    },
    {
      product: '90 d',
      quantity: 0,
      volume: 0
    },
    {
      product: '6 mnd',
      quantity: 0,
      volume: 0
    },
    {
      product: '12 mnd',
      quantity: 0,
      volume: 0
    }
  ];

  dashboardData.forEach(deposit => {
    if (deposit.type === 'FIXED') {
      fixedDeposits.push(deposit);
    }
  });

  dashboardData.forEach(deposit => {
    const { productId, volume } = deposit;
    switch (productId) {
      case '5': {
        sortedProducts[0].volume += volume;
        sortedProducts[0].quantity += 1;
        break;
      }
      case '7': {
        sortedProducts[1].volume += volume;
        sortedProducts[1].quantity += 1;
        break;
      }
      case '2': {
        sortedProducts[2].volume += volume;
        sortedProducts[2].quantity += 1;
        break;
      }
      case '3': {
        sortedProducts[3].volume += volume;
        sortedProducts[3].quantity += 1;
        break;
      }
      default: {
        return 0;
      }
    }
  });

  useEffect(() => {
    dispatch(actions.getDashboardData());
  }, []);

  const Card = props => {
    const { headerText } = props;
    return (
      <View style={styles.container}>
        <View style={styles.header}>
          <Text style={styles.headerText}>{headerText}</Text>
        </View>
        {props.children}
      </View>
    );
  };

  return (
    <View style={styles.wrapper}>
      <DashboardScrollBar />
      <ScrollView style={styles.wrapper}>
        {sortedProducts.length > 0 ? (
          <Card headerText="Produkter">
            <View style={{ margin: 10, paddingBottom: 20 }}>
              {sortedProducts.map((deposit, i) => {
                return deposit.quantity > 0 ? (
                  <Products key={i} deposit={deposit} pKey={i} />
                ) : null;
              })}
            </View>
          </Card>
        ) : null}
        {fixedDeposits.length > 0 ? (
          <Card headerText="Forfall fastrenteavtaler">
            <View style={{ margin: 10, paddingBottom: 20 }}>
              {fixedDeposits.map((deposit, i) => {
                return (
                  <ForTermination
                    key={i}
                    deposit={deposit}
                    date={new Date(deposit.expire)}
                    ftKey={i}
                  />
                );
              })}
            </View>
          </Card>
        ) : null}
      </ScrollView>
    </View>
  );
};

const primaryText = 'MuseoSansRounded-700';
const primaryTextBold = 'MuseoSansRounded-900';

const styles = StyleSheet.create({
  wrapper: {
    flex: 1,
    flexDirection: 'column',
    backgroundColor: '#EEEEEE'
  },
  container: {
    flexDirection: 'column',
    borderRadius: 15,
    borderWidth: StyleSheet.hairlineWidth,
    margin: 15,
    backgroundColor: 'white',
    overflow: 'hidden'
  },
  header: {
    backgroundColor: '#6699CC',
    alignItems: 'center',
    paddingTop: 5,
    paddingBottom: 5
  },
  headerText: {
    fontSize: 32,
    fontFamily: primaryText,
    color: 'white'
  },
  primaryText: {
    fontFamily: primaryText,
    fontSize: 18,
    color: 'black'
  },
  secondaryText: {
    fontFamily: primaryText,
    fontSize: 14,
    color: 'black',
    textAlign: 'center'
  }
});

export default DashboardBank;
