import React from 'react';
import { View, Text, StyleSheet, TouchableOpacity, Modal, Platform } from 'react-native';
import { Ionicons } from '@expo/vector-icons';
import * as LocalAuthentication from 'expo-local-authentication';

const AndroidModal = props => {
  return (
    <Modal
      animationType="fade"
      transparent={true}
      visible={props.modalVisible}
      onShow={props.scanFingerPrint}
    >
      <View style={modalStyle.centeredView}>
        <View style={modalStyle.modalView}>
          <Text style={modalStyle.loginText}>Logg inn med fingeravtrykk</Text>
          <Ionicons
            name="ios-finger-print"
            size={70}
            color={'darkgray'}
            style={{ marginTop: 20 }}
          />

          <View style={{ marginBottom: 20 }}>
            {props.failedCount > 0 && (
              <Text style={modalStyle.failedCountText}>
                Autentisering mislykket. Vennligst prøv igjen.
              </Text>
            )}
          </View>

          <TouchableOpacity
            style={modalStyle.cancelButton}
            onPress={() => {
              LocalAuthentication.cancelAuthenticate();
              setModalVisible(false);
            }}
          >
            <Text style={modalStyle.cancelButtonText}>Avbryt</Text>
          </TouchableOpacity>
        </View>
      </View>
    </Modal>
  );
};
const modalStyle = StyleSheet.create({
  centeredView: {
    flex: 1,
    justifyContent: 'flex-end',
    flexDirection: 'column',
    alignItems: 'center',
    opacity: 0.99,
    backgroundColor: 'rgba(100,100,100, 0.5)'
  },
  modalView: {
    backgroundColor: '#fff',
    padding: 35,
    height: '50%',
    width: '100%',
    alignItems: 'center',
    shadowColor: '#000',
    shadowOffset: {
      width: 1,
      height: 2
    },
    shadowOpacity: 0.25,
    shadowRadius: 3.84,
    elevation: 5
  },
  cancelButton: {
    borderRadius: 12,
    borderColor: '#8B0000',
    borderWidth: 1,
    backgroundColor: '#FF0000',
    padding: 10,
    shadowColor: '#8B0000',
    shadowOpacity: 1,
    shadowRadius: 2,
    shadowOffset: { width: 1, height: 3 },
    elevation: 10,
    overflow: Platform.OS === 'android' && Platform.Version >= 21 ? 'hidden' : 'visible'
  },
  cancelButtonText: {
    color: '#fff',
    fontSize: 16,
    fontFamily: 'MuseoSansRounded-500'
  },
  failedCountText: {
    color: '#FF0000',
    fontSize: 14,
    fontFamily: 'MuseoSansRounded-500'
  },
  loginText: {
    fontFamily: 'MuseoSansRounded-500',
    margin: 10,
    fontSize: 20
  }
});

export default AndroidModal;
