import React, { useState } from 'react';
import { StyleSheet, View, Platform } from 'react-native';
import { WebView } from 'react-native-webview';
import { useSelector, useDispatch } from 'react-redux';

import * as actions from '../../../store/actions/action';

import MainNavigator from '../../../navigations/MainNavigator';
import PromptScreen from '../PromptScreen/PromptScreen';

const BankIDLogin = () => {
  const URI = 'https://market.test.fixrate.org/dummylogin';
  const JWTurl = 'https://market.test.fixrate.org/api/session/jwt';

  const haveReadPromptMessage = useSelector(state => state.init.loading.promptMessage);
  const haveBiometricHardware = useSelector(state => state.init.loading.hasBiometricHardware);
  const dispatch = useDispatch();
  const [isDone, setIsDone] = useState(false);

  const callback = async event => {
    if (Platform.OS === 'android') {
      fetch(JWTurl, {
        credentials: 'include'
      }).then(response => {
        if (response.status === 200) {
          dispatch(actions.setJWT(response.text()));
          dispatch(actions.setAuth(true));
          setIsDone(true);
        }
      });
    } else {
      const jwt = event.nativeEvent.data;
      dispatch(actions.setJWT(jwt));
      dispatch(actions.setAuth(true));
      setIsDone(true);
    }
  };

  const injectedJavaScriptAndroid = `
    if(loginStatus) { 
        window.ReactNativeWebView.postMessage(loginStatus);    
    }`;

  const injectedJavaScript = `
        let jwt = "";
        if (loginStatus) {
            let xhr = new XMLHttpRequest();
            
            xhr.open("GET",'${JWTurl}');
            xhr.responseType = 'text/plain';
            xhr.send();
            xhr.onload = function() {
                if (xhr.status === 200) {
                    let response = xhr.response;
                    jwt = xhr.response;
                    window.ReactNativeWebView.postMessage(jwt, '*');
                }
            }
        }
        true`;

  if (!isDone) {
    return (
      <View style={styles.wrapper}>
        <WebView
          style={styles.container}
          source={{
            uri: URI,
            withCredentials: true
          }}
          scalesPageToFit={true}
          javaScriptEnabled={true}
          injectedJavaScript={
            Platform.OS === 'android' ? injectedJavaScriptAndroid : injectedJavaScript
          }
          onMessage={callback}
          originWhitelist={['*']}
        />
      </View>
    );
  } else if (isDone && !haveReadPromptMessage && haveBiometricHardware.length !== 0) {
    return <PromptScreen />;
  } else {
    return (
      <View style={styles.wrapper}>
        <MainNavigator />
      </View>
    );
  }
};

const styles = StyleSheet.create({
  wrapper: {
    flex: 1,
    flexDirection: 'column'
  },
  container: {
    flex: 1,
    marginTop: 70
  }
});
export default BankIDLogin;
