/* eslint-disable react/jsx-filename-extension */
import React, { useState, useEffect } from 'react';
import { StyleSheet, Platform } from 'react-native';
import { WebView } from 'react-native-webview';
import { useSelector, useDispatch } from 'react-redux';
import { Notifications } from 'expo';

import * as actions from '../../store/actions/action';

import NotificationHandler from '../../utils/notifications';

const Marketplace = () => {
  const URI = 'https://market.test.fixrate.org/marketplace';
  const [WebviewReloaded, setWebviewReloaded] = useState(false);
  const [status, setStatus] = useState(false);
  const jwt = useSelector(state => state.init.jwt);
  const expoToken = useSelector(state => state.init.loading.deviceToken);

  const dispatch = useDispatch();
  let WebViewRef;

  const handleNotification = async notification => {
    console.log('Notification: ', notification);
    const { origin } = notification;
    const { title, body, action } = notification.data;

    if (origin === 'received') {
      console.log('origin === received');
      const localnotification = {
        title: title,
        body: body,
        data: {
          _displayInForeground: true
        }
      };
      let sendTimer = Date.now();
      sendTimer += 1000;
      const notificationOption = { time: sendTimer };
      Notifications.scheduleLocalNotificationAsync(localnotification, notificationOption);
      if (action === 'NEW_AD') {
        dispatch(actions.getAds());
      } else {
        const { associationType } = notification.data;
        dispatch(actions.getOrders(associationType));
      }
    } else if (origin === 'selected') {
      console.log('origin === selected');
      if (action === 'NEW_AD') {
        dispatch(actions.getAds());
      } else {
        const { associationType } = notification.data;
        dispatch(actions.getOrders(associationType));
      }
    }
  };

  useEffect(() => {
    console.log('[Marketplace.js] --> useEffect().');
    NotificationHandler.registerForPushNotifications();
    Notifications.addListener(handleNotification);
  }, []);
  // End pushnotifications

  const callbackFetch = async () => {
    await fetch('https://market.test.fixrate.org/api/session/jwt', {
      method: 'POST',
      body: jwt
    }).then(response => {
      if (response.status === 200) {
        setStatus(true);
      }
    });
    return status;
  };

  const callback = event => {
    const receivedResult = event.nativeEvent.data;
    console.log('[Marketplace.js] --> callback(): ', receivedResult);
    if (!WebviewReloaded && receivedResult === 'true') {
      console.log('[Marketplace.js] --> Reloading webview.');
      setWebviewReloaded(true);
      WebViewRef.reload();
    } else {
      // Invalid session...
      dispatch(actions.logOut(expoToken, true));
    }
  };

  //  Fetching the sessionData from api/session.
  //  actions.fetchSession does a fetch to api/session
  //  and sets the sessionData in store to the result.
  if (WebviewReloaded) {
    console.log('[Marketplace.js] --> Fetch().');
    dispatch(actions.fetchSession(expoToken));
    dispatch(actions.getAds());
    dispatch(actions.getBanks());
    dispatch(actions.getDashboard());
  }

  // eslint-disable-next-line no-unused-vars
  const injectedJavascript = `
        if (!${WebviewReloaded}) {
            let xhr = new XMLHttpRequest();
            xhr.open("POST",'https://market.test.fixrate.org/api/session/jwt');
            xhr.setRequestHeader('Content-Type','text/plain');
            xhr.send('${jwt}');
            xhr.onload = function() {
                if(xhr.status === 200){
                    window.ReactNativeWebView.postMessage(true, "*");
                }else{
                    window.ReactNativeWebView.postMessage(false, "*");
                }
            };
        }
    `;

  const injectedJavaScriptAndroid = `
    if (!${WebviewReloaded}) {
      if (${callbackFetch}) { 
        window.ReactNativeWebView.postMessage(true) 
      }  
    }`;

  return (
    <WebView
      // eslint-disable-next-line no-return-assign
      ref={WEBVIEW_REF => (WebViewRef = WEBVIEW_REF)}
      source={{ uri: URI, withCredentials: true }}
      scalesPageToFit
      javaScriptEnabled
      injectedJavaScript={
        Platform.OS === 'android' ? injectedJavaScriptAndroid : injectedJavascript
      }
      style={styles.container}
      onMessage={callback}
    />
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1
  }
});
export default Marketplace;
