import React from 'react';
import { StyleSheet, View, Text, TouchableOpacity } from 'react-native';
import { useSelector } from 'react-redux';

const NewAds = ({ item, nav }) => {
  const banks = useSelector(state => state.init.banks);

  let bankName = '';
  let productName = '';
  let bankGroup = '';
  let interestDescription = '';
  let niborm3m = '';
  let productDesciption = '';
  const published = new Date(item.published).toLocaleDateString();

  const findBankName = bankId => {
    banks.forEach(element => {
      if (bankId === element.id) {
        bankName = element.name;
        bankGroup = element.bankGroup;
      }
    });
  };

  const findProductName = productId => {
    switch (productId) {
      case '1': {
        productName = '3 mnd';
        interestDescription = 'Fastrente';
        productDesciption = 'Bindingstid';
        break;
      }
      case '2': {
        productName = '6 mnd';
        interestDescription = 'Fastrente';
        productDesciption = 'Bindingstid';
        break;
      }
      case '3': {
        productName = '12 mnd';
        interestDescription = 'Fastrente';
        productDesciption = 'Bindingstid';
        break;
      }
      case '5': {
        productName = '31 d';
        interestDescription = 'Flytende rente';
        productDesciption = 'Oppsigelsestid';
        niborm3m = `NIBOR3M ${item.interestWithoutNibor}%`;
        break;
      }
      case '7': {
        productName = '90 d';
        interestDescription = 'Flytende rente';
        productDesciption = 'Oppsigelsestid';
        niborm3m = `NIMOR3M ${item.interestWithoutNibor}%`;
        break;
      }
      default: {
        productName = 'Finner ikke produkt.';
        break;
      }
    }
  };

  function findInterestDescription() {
    return item.productId === '1' || item.productId === '2' || item.productId === '3' ? (
      <Text style={styles.interest}>{item.interest}% </Text>
    ) : (
      <Text style={styles.interest}>
        <Text>{item.interest}%</Text>
      </Text>
    );
  }

  findBankName(item.bankId);
  findProductName(item.productId);

  return (
    <View style={styles.container}>
      <View style={styles.header}>
        <View>
          <Text style={styles.headerText}>
            <Text>{bankName}</Text>
            <Text style={styles.headerTextSecondary}>
              <Text>
                {' '}
                {bankGroup}
                {'\n'}
              </Text>
              <Text style={styles.published}>Publisert: {published}</Text>
            </Text>
          </Text>
        </View>
      </View>

      <View style={styles.sections}>
        <View>
          <Text style={styles.interestDescription}>{interestDescription}</Text>
          {findInterestDescription()}
          <Text style={styles.nibor3m}>{niborm3m}</Text>
        </View>
        <View>
          <Text style={styles.interestDescription}>{productDesciption}</Text>
          <Text style={styles.product}>{productName}</Text>
        </View>
      </View>

      <View style={styles.sections}>
        <View>
          <Text style={styles.volumeText}>Minimumsinnskudd</Text>
          <Text style={styles.volume}>{item.min} mill</Text>
        </View>
        <View>
          <Text style={styles.volumeText}>Maximumsinnskudd</Text>
          <Text style={styles.volume}>{item.max} mill</Text>
        </View>
      </View>

      <View
        style={{
          flexDirection: 'row',
          justifyContent: 'space-evenly',
          alignItems: 'center',
          marginTop: 10
        }}
      >
        <TouchableOpacity
          onPress={() => nav.navigate('Marketplace')}
          style={styles.marketplaceButton}
        >
          <Text style={styles.marketplaceButtonText}>Gå til markedsplassen</Text>
        </TouchableOpacity>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    flexDirection: 'column',
    height: '100%',
    paddingBottom: 20,
    borderWidth: 1,
    borderColor: '#6699CC',
    borderRadius: 15,
    marginTop: 20,
    overflow: 'hidden',
    backgroundColor: 'white'
  },
  header: {
    flexDirection: 'row',
    backgroundColor: '#6699CC',
    padding: 3
  },
  headerText: {
    fontFamily: 'MuseoSansRounded-900',
    color: '#EEEEEE',
    fontSize: 23,
    padding: 8
  },
  headerTextSecondary: {
    color: 'rgba(0,0,0,0.9)',
    opacity: 0.4,
    fontSize: 15
  },
  published: {
    color: 'rgba(0,0,0,0.9)',
    fontSize: 15,
    fontFamily: 'MuseoSansRounded-700'
  },
  sections: {
    flexDirection: 'row',
    justifyContent: 'space-evenly',
    margin: 5
  },
  interest: {
    alignSelf: 'center',
    fontFamily: 'MuseoSansRounded-700',
    fontSize: 32,
    color: 'rgba(0,0,0,0.7)'
  },
  interestDescription: {
    marginTop: 5,
    fontSize: 18,
    fontFamily: 'MuseoSansRounded-700',
    color: 'rgba(0,0,0,0.5)'
  },
  interestWithNibor: {
    fontSize: 20
  },
  nibor3m: {
    alignSelf: 'center',
    fontFamily: 'MuseoSansRounded-700',
    color: 'rgba(0,0,0,0.5)'
  },
  product: {
    alignSelf: 'center',
    fontFamily: 'MuseoSansRounded-700',
    fontSize: 32,
    color: 'rgba(0,0,0,0.7)'
  },
  volumeText: {
    marginTop: 5,
    alignSelf: 'center',
    fontFamily: 'MuseoSansRounded-500',
    color: 'rgba(0,0,0,0.5)'
  },
  volume: {
    fontFamily: 'MuseoSansRounded-700',
    fontSize: 20,
    color: 'rgba(0,0,0,0.7)',
    alignSelf: 'center'
  },
  roundedCorners: {
    borderRadius: 12,
    backgroundColor: 'white',
    margin: 8,
    padding: 6
  },
  marketplaceButton: {
    borderRadius: 12,
    borderColor: '#99C157',
    backgroundColor: '#99C157',
    shadowColor: '#82A44A',
    borderWidth: 1,
    padding: 10,
    shadowOpacity: 1,
    shadowRadius: 1,
    shadowOffset: { width: 1, height: 3 },
    elevation: 6
  },
  marketplaceButtonText: {
    fontSize: 15,
    fontFamily: 'MuseoSansRounded-700',
    color: 'white'
  }
});

export default NewAds;
