import React from 'react';
import { StyleSheet, View, Text, ScrollView, Alert, TouchableOpacity } from 'react-native';
import { useSelector, useDispatch } from 'react-redux';

import * as actions from '../../store/actions/action';

import CustomSwitch from '../../components/CustomSwitch';
import LogoutIcon from '../../assets/icons/LogoutIcon';

const NotificationSettings = () => {
  const dispatch = useDispatch();

  const expoToken = useSelector(state => state.init.loading.deviceToken);
  const biometricLogin = useSelector(state => state.init.loading.biometric);
  const promptMessage = useSelector(state => state.init.loading.promptMessage);
  const pushSettings = useSelector(state => state.init.pushSettings);
  const associationType = useSelector(state => state.init.sessionData.organisationType);

  const Content = pushSettings.map(e => {
    return (
      <CustomSwitch
        action={e.notificationType}
        label={e.label}
        labelDescription={e.description}
        state={e.notify === 1}
        key={e.notificationType}
        onChange={newValue => {
          dispatch(
            actions.setPushSettings(expoToken, newValue, e.notificationType, associationType)
          );
        }}
      />
    );
  });

  const label = biometricLogin
    ? 'Deaktiverer biometrisk innlogging'
    : 'Aktiverer biometrisk innlogging';
  const labelDesc = biometricLogin
    ? 'Er du sikker på at du vil deaktivere biometrisk innlogging?'
    : 'Er du sikker på at du vil aktivere biometrisk innlogging?';

  function dispatchAuth(newValue) {
    dispatch(actions.setReAuth(newValue));
    dispatch(actions.setPrompt(newValue, promptMessage, expoToken));
  }

  const DescText = props => (
    <View style={styles.descText}>
      <View style={{ flexDirection: 'column' }}>
        <View style={{ flexDirection: 'row', justifyContent: 'flex-start' }}>
          <Text
            style={{
              fontSize: 25,
              marginBottom: 10,
              fontWeight: 'bold',
              fontFamily: 'MuseoSansRounded-700'
            }}
          >
            {props.title}
          </Text>
        </View>
      </View>
    </View>
  );

  return (
    <ScrollView style={{ backgroundColor: '#EEEEEE' }}>
      <View style={styles.container}>
        <DescText title="Pushvarsler" />
        {Content}
        <DescText title="Innlogging" />
        <View>
          <CustomSwitch
            label={
              biometricLogin ? 'Deaktiver biometrisk innlogging' : 'Aktiver biometrisk innlogging'
            }
            labelDescription={
              biometricLogin
                ? 'Hvis du deaktiverer biometrisk innlogging må du logge inn på nytt med bankID'
                : 'Du blir nødt til å autentisere deg på nytt hvis du aktiverer biometrisk innlogging'
            }
            state={!!biometricLogin}
            onChange={newValue => {
              Alert.alert(label, labelDesc, [
                { text: 'Nei' },
                { text: 'Ja', onPress: () => dispatchAuth(newValue) }
              ]);
            }}
          />
        </View>
      </View>

      <View style={{ flexDirection: 'row', justifyContent: 'center', alignItems: 'center' }}>
        <TouchableOpacity
          style={styles.btnStyle}
          onPress={() => {
            Alert.alert(
              'Logger ut fra FixrateApp',
              'Er du sikker på at du vil logge deg ut fra FixrateApp?',
              [
                { text: 'Avbryt' },
                {
                  text: 'Ok',
                  onPress: () => dispatch(actions.logOut(expoToken, true))
                }
              ],
              { cancelable: false }
            );
          }}
        >
          <View style={{}}>
            <Text style={styles.loggOutButtonText}>
              <Text>
                <LogoutIcon style={{ color: '#333', height: 21, width: 25 }} />{' '}
              </Text>
              <Text>Logg ut</Text>
            </Text>
          </View>
        </TouchableOpacity>
      </View>
    </ScrollView>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    flexDirection: 'column',
    margin: 20,
    backgroundColor: '#EEEEEE'
  },
  descText: {
    borderBottomWidth: 1,
    borderColor: '#D3D3D3'
  },
  headlineText: {
    marginBottom: 20,
    fontSize: 17
  },
  alertBox: {
    flexDirection: 'row',
    justifyContent: 'flex-end',
    alignSelf: 'center',
    alignContent: 'flex-end',
    backgroundColor: '#6699cc',
    borderRadius: 10,
    marginTop: 30,
    marginBottom: 30
  },
  loggOutButton: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignSelf: 'center',
    backgroundColor: '#6699cc',
    borderRadius: 12,
    marginTop: 30,
    marginBottom: 30,
    padding: 12
  },
  loggOutButtonText: {
    fontFamily: 'MuseoSansRounded-500',
    color: 'white',
    fontSize: 20
  },
  btnStyle: {
    borderRadius: 15,
    borderColor: '#6699cc',
    borderWidth: 1,
    backgroundColor: '#6699cc',
    padding: 10,
    shadowColor: '#5682AD',
    shadowOpacity: 1,
    shadowRadius: 1,
    shadowOffset: { width: 1, height: 3 },
    elevation: 10
  }
});
export default NotificationSettings;
