import React, { useState, useEffect } from 'react';
import { useSelector } from 'react-redux';
import { View, Text, StyleSheet, TouchableOpacity } from 'react-native';
import { Ionicons } from '@expo/vector-icons';

const TodoItem = ({ item, nav }) => {
  const { orderState } = item;
  const { productId } = item.ad;
  const orderAccountNumber = item.toAccount;

  const session = useSelector(state => state.init.sessionData);
  const banks = useSelector(state => state.init.banks);
  const { id, associations } = useSelector(state => state.init.sessionData);
  const rateChange = useSelector(state => state.init.interestRateChange);
  const organisationUsers = useSelector(state => state.init.organisationUsers);

  const [bankName, setBankName] = useState('Ugyldig bankid.');

  let orderText = '';
  let productName = '';
  let taskDescription = '';

  let SignOrder = () => <View />;

  const CardButton = props => {
    const { url, headerTitle, buttonText } = props;
    return (
      <View style={styles.button}>
        <TouchableOpacity
          onPress={() => {
            nav.navigate({
              routeName: 'WebviewPage',
              params: {
                url: url,
                headerTitle: headerTitle
              }
            });
          }}
        >
          <Text style={{ color: '#fff', fontFamily: primaryTextBold }}>{buttonText}</Text>
        </TouchableOpacity>
      </View>
    );
  };

  switch (orderState) {
    case 'READY_FOR_SIGNING': {
      orderText = 'Kontoavtale klar for signering';

      SignOrder = () => {
        const { userId, name } = item.accountCreator;
        if (id === userId) {
          return (
            <CardButton
              url="https://market.test.fixrate.org/orders/signing"
              headerTitle="Signer"
              buttonText="Ta meg til signering"
            />
          );
        }
        return (
          <View style={styles.roundedCorners}>
            <Text style={styles.productText}>Må signeres av {name}</Text>
          </View>
        );
      };

      break;
    }
    case 'INITIAL_PROCESSING': {
      orderText = 'Ny bestilling';
      taskDescription = 'Opprett kontoavtale';

      break;
    }
    case 'READY_FOR_TRANSACTION': {
      const itemOrganisationId = item.depositor.id;
      orderText = 'Ordre klar for betaling';

      let canPay = false;
      associations.forEach(org => {
        if (org.organisation.id === itemOrganisationId) {
          org.roles.forEach(role => {
            if (role === 'DEPOSITOR_PAYMENT') {
              canPay = true;
            }
          });
        }
      });

      if (canPay) {
        SignOrder = () => {
          return (
            <CardButton
              url="https://market.test.fixrate.org/orders/transaction"
              headerTitle="Klar for betaling"
              buttonText="Ta meg til bekreftelse"
            />
          );
        };
      } else {
        let firstName;
        let lastName;
        organisationUsers.forEach(org => {
          if (org.id === itemOrganisationId) {
            org.users.forEach(user => {
              user.roles.forEach(role => {
                if (role === 'DEPOSITOR_PAYMENT') {
                  firstName = user.firstName;
                  lastName = user.lastName;
                }
              });
            });
          }
        });
        SignOrder = () => {
          return (
            <View style={styles.roundedCorners}>
              <Text style={styles.productText}>
                Må bekreftes av {firstName} {lastName}
              </Text>
            </View>
          );
        };
      }
      break;
    }

    case 'READY_FOR_APPROVAL': {
      orderText = 'Konto klar aktivering';
      taskDescription = 'Aktiver konto';
      break;
    }

    case 'READY_FOR_TRANSACTION_CONFIRMATION': {
      orderText = 'Bekreft overføring av innskuddsbeløp';
      taskDescription = 'Bekreft at beløpet har blitt overført';
      break;
    }

    case 'CANCELED': {
      orderText = 'Innskudd avvist';
      SignOrder = () => {
        return (
          <CardButton
            url="https://market.test.fixrate.org/orders/canceled"
            headerTitle="Avviste bestillinger"
            buttonText="Ta meg til avviste bestillinger"
          />
        );
      };
      break;
    }

    case 'COMPLETED': {
      if (session.organisationType === 'DEPOSITOR') {
        orderText = 'Renteendring';
        let rateChangeUrl = '';
        rateChange.forEach(order => {
          if (order.accountNumber === orderAccountNumber) {
            rateChangeUrl = order.depositId;
          }
        });
        SignOrder = () => {
          return (
            <CardButton
              url={'https://market.test.fixrate.org/portfolio/id/' + rateChangeUrl}
              headerTitle="Renteendring"
              buttonText="Ta meg til renteendringen"
            />
          );
        };
      } else {
        orderText = 'Oppsigelse av innskudd';
        taskDescription = 'Bekreft oppsigelse av innskudd';
      }

      break;
    }

    default: {
      orderText = 'Ugyldig orderState';
      break;
    }
  }

  switch (productId) {
    case '1': {
      productName = '3 mnd';
      break;
    }
    case '2': {
      productName = '6 mnd';
      break;
    }
    case '3': {
      productName = '12 mnd';
      break;
    }
    case '5': {
      productName = '31 d';
      break;
    }
    case '7': {
      productName = '90 d';
      break;
    }
    default: {
      productName = 'Finner ikke produkt.';
      break;
    }
  }

  useEffect(() => {
    banks.forEach(bank => {
      if (item.ad.bankId === bank.id) {
        setBankName(bank.name);
      }
    });
  }, []);

  return (
    <View style={styles.container}>
      <View>
        <Text numberOfLines={4} style={styles.orderState}>
          {orderText}
        </Text>
      </View>

      <View>
        <Text numberOfLines={2} style={styles.depositorText}>
          {item.depositor.name}
        </Text>
      </View>

      <View>
        <Ionicons name="ios-arrow-round-down" size={42} color="white" />
      </View>

      <View>
        <Text style={styles.bankName}>
          {session.organisationType === 'BANK' ? taskDescription : bankName}
        </Text>
      </View>

      <View>
        <Text style={styles.volumeText}>{item.volume} 000 000 kr</Text>
      </View>

      <View style={{ flex: 1, flexDirection: 'row' }}>
        <View style={styles.roundedCorners}>
          <Text style={styles.productText}>{item.ad.interest}%</Text>
        </View>

        <View style={styles.roundedCorners}>
          <Text style={styles.productText}>{productName}</Text>
        </View>
      </View>

      <SignOrder />
    </View>
  );
};

const primaryText = 'MuseoSansRounded-500';
const primaryTextBold = 'MuseoSansRounded-900';

const styles = StyleSheet.create({
  container: {
    flex: 1,
    flexDirection: 'column',
    alignItems: 'center',
    height: '100%',
    paddingTop: 10,
    paddingBottom: 10,
    backgroundColor: '#6699CC',
    borderRadius: 15,
    marginTop: 20
  },
  depositorText: {
    marginTop: 10,
    fontSize: 20,
    fontFamily: primaryText,
    color: 'rgba(255,255,255,0.7)',
    textAlign: 'center'
  },
  volumeText: {
    fontFamily: 'MuseoSansRounded-700',
    fontSize: 25,
    color: '#FFFFFF'
  },
  roundedCorners: {
    borderRadius: 12,
    backgroundColor: 'white',
    margin: 8,
    padding: 6
  },
  button: {
    borderColor: '#99C157',
    backgroundColor: '#99C157',
    shadowColor: '#82A44A',
    borderRadius: 12,
    margin: 8,
    padding: 10,
    borderWidth: 1,
    shadowOpacity: 1,
    elevation: 6,
    shadowOffset: { width: 1, height: 3 }
  },
  bankName: {
    color: 'white',
    fontFamily: 'MuseoSansRounded-700',
    fontSize: 22,
    textAlign: 'center',
    marginBottom: 10
  },
  productText: {
    fontFamily: primaryTextBold,
    color: '#6699CC',
    textAlign: 'center'
  },
  orderState: {
    fontFamily: primaryTextBold,
    fontSize: 32,
    color: 'white',
    textAlign: 'center'
  }
});

export default TodoItem;
