import {
  SET_SESSION,
  SET_JWT,
  SET_LOADED,
  SET_PROMPT,
  SET_AUTH,
  SET_REAUTH,
  LOG_OUT,
  GET_PUSHSETTINGS,
  SET_PUSHSETTINGS,
  GET_ORG_USERS,
  GET_ORDERS,
  GET_ADS,
  GET_BANKS,
  GET_INTEREST_RATE_CHANGE,
  GET_DASHBOARD,
  GET_DASHBOARD_DATA
} from '../actions/action';

const initialState = {
  authenticated: false,
  reAuth: false,
  appUsageRole: '',
  loading: {
    loaded: false,
    deviceToken: '',
    promptMessage: false,
    biometric: false,
    hasBiometricHardware: []
  },
  dashboard: {},
  dashboardData: [],
  jwt: '',
  sessionData: [''],
  pushSettings: [''],
  orders: [],
  ads: [''],
  banks: [''],
  interestRateChange: [''],
  numbOfNewAds: 0,
  numbOfNewTodo: 0,
  organisationUsers: []
};

const initReducer = (state = initialState, action) => {
  let index = null;
  let updatedState = null;

  switch (action.type) {
    case SET_SESSION: {
      return {
        ...state,
        sessionData: action.sessionData
      };
    }

    case SET_JWT: {
      return {
        ...state,
        jwt: action.payload.jwt
      };
    }

    case SET_LOADED: {
      console.log('[reduce.js] -> SET_LOADED', action.payload);
      updatedState = {
        loaded: true,
        deviceToken: action.payload.result.expoToken,
        promptMessage: action.payload.result.firstPrompt,
        biometric: action.payload.result.biometri,
        hasBiometricHardware: action.payload.hasBiometricHardware
      };
      return {
        ...state,
        loading: updatedState
      };
    }

    case SET_PROMPT: {
      console.log('[reduce.js] -> SET_PROMPT');
      updatedState = {
        loaded: state.loading.loaded,
        deviceToken: state.loading.deviceToken,
        promptMessage: action.payload.promptReceived,
        biometric: action.payload.bioAnswer
      };
      return {
        ...state,
        loading: updatedState
      };
    }

    case SET_AUTH: {
      console.log('[reduce.js] -> SET_AUTH');
      return {
        ...state,
        authenticated: action.payload.newValue
      };
    }

    case SET_REAUTH: {
      console.log('[reduce.js] --> SET_REAUTH');
      return {
        ...state,
        reAuth: action.payload.newValue
      };
    }

    case GET_PUSHSETTINGS: {
      console.log('[reduce.js] --> SET_PUSHSETTINGS');
      return {
        ...state,
        pushSettings: action.payload.result
      };
    }

    case SET_PUSHSETTINGS: {
      index = state.pushSettings.findIndex(
        e => e.notificationType === action.payload.notificationType
      );
      updatedState = [...state.pushSettings];
      updatedState[index].notify = action.payload.newValue;
      return {
        ...state,
        pushSettings: updatedState
      };
    }

    case GET_ORDERS: {
      return {
        ...state,
        numbOfNewTodo: action.payload.length,
        orders: action.payload
      };
    }

    case GET_ADS: {
      return {
        ...state,
        numbOfNewAds: action.payload.length,
        ads: action.payload
      };
    }

    case GET_BANKS: {
      return {
        ...state,
        banks: action.payload
      };
    }

    case GET_INTEREST_RATE_CHANGE: {
      return {
        ...state,
        interestRateChange: action.payload
      };
    }

    case GET_ORG_USERS: {
      return {
        ...state,
        organisationUsers: action.payload
      };
    }

    case GET_DASHBOARD: {
      return {
        ...state,
        dashboard: action.payload
      };
    }

    case GET_DASHBOARD_DATA: {
      return {
        ...state,
        dashboardData: action.payload
      };
    }

    case LOG_OUT: {
      state = initialState;
      break;
    }

    default: {
      return state;
    }
  }
  return state;
};

export default initReducer;
