import { Alert } from 'react-native';
import * as SecureStore from 'expo-secure-store';
import * as actions from '../../store/actions/action';

const SecureStoreHandler = {
  readStore: async function(keyName, expoToken, dispatch) {
    try {
      const retrievedToken = await SecureStore.getItemAsync(keyName);
      console.log('secureStorage.js --> readStore: ', retrievedToken);
      if (!retrievedToken) {
        console.log('[SecureStoreHandler.js] --> readStore(). No token found!');
        dispatch(actions.logOut(expoToken, true));
        Alert.alert('Noe gikk galt. Vennligst logg inn igjen');
      } else {
        console.log('[SecureStoreHandler.js] --> readStore(). Found token!');
        dispatch(actions.setJWT(retrievedToken));
        dispatch(actions.setAuth(true));
      }
    } catch (e) {
      console.log('[SecureStoreHandler.js] --> function readStoreError: ', e);
    }
  },
  setKeyInStore: async function(promptAnswer, keyName, keyValue, expoToken, dispatch) {
    if (promptAnswer) {
      try {
        console.log('[SecureStoreHandler.js] --> setKeyInStore()');
        await SecureStore.setItemAsync(keyName, keyValue.toString());
      } catch (e) {
        console.log('[SecureStoreHandler.js] --> setKeyInStoreError: ', e);
      }
    }
    dispatch(actions.setPrompt(promptAnswer, true, expoToken));
  }
};

export default SecureStoreHandler;
